
import setuptools

setuptools.setup(
    name="gymgen",
    version="0.0.1",
    author="AutoGen Developers",
    author_email="your_email@example.com",
    description="GymGen",
    long_description="GymGen",
    long_description_content_type="text/markdown",
    url="https://github.com/microsoft/autogen",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)
